@@ -145,7 +145,7 @@ end
 -- a specified number of padding squares.
 function procedural.border(params)
   local x1,y1 = 0,0
-  local x2,y2 = dgn.max_bounds()
+  local x2,y2 = dgn.builder_bounds()
   x2 = x2 - 1
   y2 = y2 - 1
   if params.x1 ~= nil then x1 = params.x1 end
@@ -181,7 +181,7 @@ end
 function procedural.box(params)
 
   local x1,y1 = 0,0
-  local x2,y2 = dgn.max_bounds()
+  local x2,y2 = dgn.builder_bounds()
   x2 = x2 - 1
   y2 = y2 - 1
   if params.x1 ~= nil then x1 = params.x1 end
@@ -258,7 +258,7 @@ end
 -- library file if it's going to be used more than once
 function procedural.river(params)
 
-  local gxm,gym = dgn.max_bounds()
+  local gxm,gym = dgn.builder_bounds()
 
   local horizontal = params.horizontal == nil and true or params.horizontal
   local width = params.width or 15
@@ -460,7 +460,7 @@ end
 -- Render functions
 function procedural.render_map(e, fval, fresult)
 
-  local gxm,gym = dgn.max_bounds()
+  local gxm,gym = dgn.builder_bounds()
   e.extend_map { width = gxm, height = gym, fill = 'x' }
   for x = 1,gxm-2,1 do
     for y = 1,gym-2,1 do
