@@ -6,10 +6,8 @@
 --  any armour
 --  any jewellery
 --  any weapon
---  any book
 --  any scroll
 --  any potion
---  any wand
 --  runes
 --  the horn of Geryon
 --  your piety!
@@ -168,7 +166,7 @@ function TroveMarker:debug_diag (marker)
     self:search_for_item(marker, nil, items.inventory(), true)
   end
 
-  if crawl.yesno("Run diagonstic on floor?", true, "n") then
+  if crawl.yesno("Run diagnostic on floor?", true, "n") then
     local _x, _y = marker:pos()
     self:search_for_item(marker, nil, dgn.items_at(_x, _y), true)
   end
@@ -341,25 +339,10 @@ function TroveMarker:item_name(do_grammar)
     else
       s = s .. " " .. item.base_type .. " of"
     end
-  elseif item.base_type == "book" then
-    books = {"Necronomicon", "Young Poisoner's Handbook", "Grand Grimoire"}
-    if util.contains(books, item.sub_type) then
-      if do_grammar == false then
-        return item.sub_type
-      else
-        return "a " .. item.sub_type
-      end
-    end
-  elseif item.base_type == "wand" then
-    s = s .. " wand of"
   end
 
   s = s .. " " .. item.sub_type
 
-  if item.base_type == "wand" then
-    s = s .. " (" .. item.plus1 .. ")"
-  end
-
   if item.base_type == "armour" or item.base_type == "weapon" then
     if item.ego_type then
       s = s .. " of " .. item.ego_type
@@ -501,7 +484,7 @@ function TroveMarker:item_with_lowest_pluses(marker, pname, dry_run, items)
       titem = it
       titem_p1 = titem.pluses()
       --crawl.mpr("Picking " .. titem.name() ..
-      --          " instead (lesser pluses instad)")
+      --          " instead (lesser pluses instead)")
       --crawl.mpr("This item p1: " .. titem_p1 .. ")
     elseif this_p1 == item.plus1 then
       titem = it
@@ -571,8 +554,7 @@ function TroveMarker:check_item_veto(marker, pname)
     if self:showing_item() then
       crawl.mpr("You don't have " .. self:item_name() .. " with you.")
     else
-      crawl.mpr("You don't have the item" .. self:plural() ..
-                " to give! Perhaps you haven't completely identified the item yet?")
+      crawl.mpr("You don't have the item" .. self:plural() .. " to give!")
     end
     return "veto"
   end
